SystemOrganization addCategory: #'GT-Setup'!

CommandLineHandler subclass: #GTImageSetupCommandLineHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Setup'!

!GTImageSetupCommandLineHandler commentStamp: 'TudorGirba 3/19/2014 12:07' prior: 0!
The command that can be triggered to setup a image right after the GToolkit configuration is loaded in a fresh Pharo image.

Example usage in a Jenkins:
./pharo $JOB_NAME.image gtimagesetup!

!GTImageSetupCommandLineHandler class methodsFor: 'as yet unclassified' stamp: 'TudorGirba 3/19/2014 11:44'!
commandName
	^ 'gtimagesetup'! !

!GTImageSetupCommandLineHandler class methodsFor: 'as yet unclassified' stamp: 'TudorGirba 3/19/2014 11:45'!
description
	^ 'Sets up the image with GToolkit specific tools and settings'! !

!GTImageSetupCommandLineHandler methodsFor: 'activation' stamp: 'TudorGirba 3/20/2014 13:42'!
activate
	"self new activate"
	self activateWithoutSaving.
	Smalltalk snapshot: true andQuit: true! !

!GTImageSetupCommandLineHandler methodsFor: 'activation' stamp: 'TudorGirba 7/23/2014 21:58'!
activateWithoutSaving
	self cleanupWorld.
"	self installGLMWhitespaceTheme."
	self installFonts.
	self installAthens.
	self installGTInspector.
	self installGTDebuggers.
	self installGTPlayground.
	self flushMCCache.
	self setPreferredSettings.
	self disableBreakingCommandPlusOKeybindingsInPharo30.
"	self loadMorphTreeMorphPatchToFixTheDebuggerInPharo30"! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 22:26'!
cleanupWorld
	World color: Color white! !

!GTImageSetupCommandLineHandler methodsFor: 'patches' stamp: 'TudorGirba 7/6/2014 08:05'!
disableBreakingCommandPlusOKeybindingsInPharo30
	"In GT we use Cmd+o extensively, and the current logic of global bindings makes it
	impossible to use when a global binding is defined even as Cmd+o+somethingelse.
	
	So, we disable all global bindings that start with Cmd+o"
	((KMRepository default globalCategories flatCollect: [ :each | each allEntries keymaps ])
		select: [ :each | each shortcut beginsWith: $o command ]) do: #disable! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
flushMCCache
	MCFileBasedRepository flushAllCaches ! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 12:04'!
installAthens
	ROPlatform setCurrent: 'athens'! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/20/2014 13:44'!
installDemoFonts
	self loadFonts.
	StandardFonts 
		setAllStandardFontsTo: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		haloFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		windowTitleFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 18);
		balloonFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		codeFont: (LogicalFont familyName: 'Source Code Pro' pointSize: 14)! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
installFonts
	self loadFonts.
	StandardFonts 
		setAllStandardFontsTo: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		haloFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		windowTitleFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 14);
		balloonFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		codeFont: (LogicalFont familyName: 'Source Code Pro' pointSize: 10)! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 6/27/2014 00:21'!
installGLMWhitespaceTheme
	GLMWhitespaceTheme 
		defaultSettings: nil;
		setPreferredWorldBackground;
		beCurrent;
		setPreferredShoutColors! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 4/3/2014 07:39'!
installGTDebuggers
	
	GTGenericStackDebugger registerToolsOn: Smalltalk tools.
	
	GTGenericStackDebugger registerExtraToolsOn: Smalltalk tools.
	GTGlamourDebugger registerToolsOn: Smalltalk tools.
	#ACGlamourDebugger asClassIfPresent: [ :acdDebugger | acdDebugger register ].
	GTSUnitDebugger registerToolsOn: Smalltalk tools.
	
	GTMoldableDebugger enableDebuggerWindowDistinctColor: true! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
installGTInspector
	GTInspector registerToolsOn: Smalltalk tools ! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
installGTPlayground
	
	GTPlayground registerToolsOn: Smalltalk tools! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'AndreiChis 4/9/2014 23:14'!
loadFonts
	#('SourceCodeProRegular' 'SourceCodeProBold' 'SourceSansProRegular' 'SourceSansProBold') do: [ :each | 
		each asSymbol asClassIfAbsent: [
			Gofer new 
				smalltalkhubUser: 'girba' project: 'FreeFonts';
				package: each;
				load ].
		"(Smalltalk at: each asSymbol) new install"
		FreeTypeFontProvider registerFont: (Smalltalk at: each asSymbol) ].
	FreeTypeSystemSettings loadFt2Library: true.
	FreeTypeFontProvider current updateFromSystem! !

!GTImageSetupCommandLineHandler methodsFor: 'patches' stamp: 'TudorGirba 7/6/2014 08:08'!
loadMorphTreeMorphPatchToFixTheDebuggerInPharo30
	Gofer new 
		smalltalkhubUser: 'Pharo' project: 'Pharo30Inbox';
		package: 'SLICE-Issue-13422-Image-crashes-because-an-open-Nautilus-browser-hangs-onto-many-objects-while-code-is-being-loaded';
		load! !

!GTImageSetupCommandLineHandler methodsFor: 'patches' stamp: 'TudorGirba 3/20/2014 13:45'!
loadOlderAthensPackagesToCorrectTheFontCachingProblem
	"
	This is a workaround fir the bug described here:
	https://pharo.fogbugz.com/f/cases/12777/Athens-font-cacheing-bug
	"
	Gofer new 
		smalltalkhubUser: 'Pharo' project: 'Pharo30';
		package: 'Athens-Cairo' constraint: [ :version |
			version author = 'MarcusDenker' and: [ version versionNumber = 51 ] ];
		package: 'Athens-Core' constraint: [ :version | 
			version author = 'MarcusDenker' and: [ version versionNumber = 34 ] ];
		load
		! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 6/27/2014 00:21'!
setPreferredSettings
	NECPreferences 
		popupShowAutomatic: false;
		expandPrefixes: true;
		popupShowWithShortcut: Character tab asShortcut.
	GTGenericStackDebugger enableStackColoring: true.
	GLMWhitespaceTheme setPreferredShoutColors.! !
